@@ -1,5 +1,5 @@
 package Dist::Zooky::DistIni;
-$Dist::Zooky::DistIni::VERSION = '0.18';
+$Dist::Zooky::DistIni::VERSION = '0.20';
 # ABSTRACT: Generates a Dist::Zilla dist.ini file
 
 use strict;
@@ -70,7 +70,7 @@ sub write {
     for qw(configure build runtime);
   $stash{$_} = $self->metadata->{$_} for qw(author license version name);
   $stash{"${_}s"} = delete $stash{$_} for qw(author license);
-  my $template = $temphead . ( $self->bundle ? q|[@| . $self->bundle . qq|]| : $tempstd );
+  my $template = $temphead . ( $self->bundle ? q|[@| . $self->bundle . qq|]| : $tempstd ) . "\n";
   my $content = $self->fill_in_string(
     $template,
     \%stash,
@@ -108,7 +108,7 @@ Dist::Zooky::DistIni - Generates a Dist::Zilla dist.ini file
 
 =head1 VERSION
 
-version 0.18
+version 0.20
 
 =head1 SYNOPSIS
 
